@@ -48,10 +48,16 @@ class ServiceResource(ClassRecord):
 
     @property
     def boto3_doc_link(self) -> str:
+        """
+        Link to boto3 docs.
+        """
         return self.service_name.get_boto3_doc_link("ServiceResource")
 
     @property
     def docstring(self) -> str:
+        """
+        Class docstring.
+        """
         return (
             "[Show boto3 documentation]"
             f"({self.boto3_doc_link})"
@@ -60,6 +66,9 @@ class ServiceResource(ClassRecord):
         )
 
     def get_types(self) -> Set[FakeAnnotation]:
+        """
+        Extract type annotations for collections and sub-resources.
+        """
         types = super().get_types()
         for collection in self.collections:
             types.update(collection.get_types())
@@ -69,6 +78,9 @@ class ServiceResource(ClassRecord):
         return types
 
     def get_all_names(self) -> List[str]:
+        """
+        Get names for `__all__` statement.
+        """
         result = [self.name]
         for resource in self.sub_resources:
             result.append(resource.name)
@@ -77,6 +89,9 @@ class ServiceResource(ClassRecord):
         return result
 
     def get_collections(self) -> List[Collection]:
+        """
+        Get a list of Service Resource collections.
+        """
         collection_names = [i.name for i in self.collections]
         result: List[Collection] = []
         result.extend(self.collections)
